@@ -21,7 +21,6 @@
 
 #include <glib-object.h>
 #include <libbiji/libbiji.h>
-#include <libgd/gd-main-view.h>
 
 G_BEGIN_DECLS
 
@@ -29,6 +28,16 @@ G_BEGIN_DECLS
 
 G_DECLARE_FINAL_TYPE (BjbController, bjb_controller, BJB, CONTROLLER, GObject)
 
+typedef enum {
+  BJB_MODEL_COLUMN_UUID,
+  BJB_MODEL_COLUMN_TITLE,
+  BJB_MODEL_COLUMN_TEXT,
+  BJB_MODEL_COLUMN_MTIME,
+  BJB_MODEL_COLUMN_COLOR,
+  BJB_MODEL_COLUMN_SELECTED,
+  BJB_MODEL_COLUMN_LAST
+} BjbModelColumnsType;
+
 BjbController * bjb_controller_new (BijiManager  *manager,
                                     GtkWindow     *bjb_window_base,
                                     gchar         *needle);
@@ -65,5 +74,23 @@ void bjb_controller_show_more (BjbController *controller);
 
 gboolean bjb_controller_get_remaining_items (BjbController *self);
 
+gboolean  bjb_controller_get_selection_mode (BjbController *self);
+
+void      bjb_controller_set_selection_mode (BjbController *self,
+                                             gboolean       selection_mode);
+
+GList    *bjb_controller_get_selection      (BjbController *self);
+
+void      bjb_controller_select_item        (BjbController *self,
+                                             const char    *iter_string);
+
+void      bjb_controller_unselect_item      (BjbController *self,
+                                             const char    *iter_string);
+
+void      bjb_controller_select_all         (BjbController *self);
+
+void      bjb_controller_unselect_all       (BjbController *self);
+
+gboolean  bjb_controller_is_all_selected    (BjbController *self);
 
 G_END_DECLS
