@@ -224,19 +224,32 @@ biji_manager_initable_init (GInitable *initable,
 
   filename = g_build_filename (g_get_user_cache_dir (),
                                g_get_application_name (),
+#if HAVE_TRACKER3
+                               "tracker3",
+#else
                                "tracker",
+#endif /* HAVE_TRACKER3 */
                                NULL);
   data_location = g_file_new_for_path (filename);
 
   /* If tracker fails for some reason,
    * do not attempt anything */
+#if HAVE_TRACKER3
+  self->connection = tracker_sparql_connection_new (TRACKER_SPARQL_CONNECTION_FLAGS_NONE,
+                                                    data_location,
+                                                    tracker_sparql_get_ontology_nepomuk (),
+                                                    NULL,
+                                                    &local_error);
+#else
   self->connection = tracker_sparql_connection_local_new (TRACKER_SPARQL_CONNECTION_FLAGS_NONE,
                                                           data_location,
                                                           NULL, NULL, NULL,
                                                           &local_error);
+#endif /* HAVE_TRACKER3 */
+
 #else
   self->connection = tracker_sparql_connection_get (NULL, &local_error);
-#endif
+#endif /* TRACKER_PRIVATE_STORE */
 
   if (local_error)
   {
@@ -552,12 +565,12 @@ on_item_trashed_cb (BijiItem *item, BijiManager *self)
 static void
 on_item_restored_cb (BijiItem *item, gchar *old_uuid, BijiManager *manager)
 {
+  const char *path = biji_item_get_uuid (item);
   if (BIJI_IS_NOTE_OBJ (item))
     biji_note_obj_save_note (BIJI_NOTE_OBJ (item));
 
-  g_hash_table_insert (manager->items,
-                       (gpointer) biji_item_get_uuid (item), item);
-  g_hash_table_remove (manager->archives, old_uuid);
+  g_hash_table_insert (manager->items, (gpointer) path, item);
+  g_hash_table_remove (manager->archives, path);
 
   biji_manager_notify_changed (manager,
                                BIJI_ARCHIVED_ITEMS,
