@@ -97,7 +97,7 @@ gboolean         biji_note_obj_set_mtime                     (BijiNoteObj* n,
                                                               gint64 time);
 
 
-const gchar     *biji_note_obj_get_last_change_date_string   (BijiNoteObj *self);
+gchar           *biji_note_obj_get_last_change_date_string   (BijiNoteObj *self);
 
 
 gint64           biji_note_obj_get_last_metadata_change_date (BijiNoteObj *note);
@@ -154,6 +154,12 @@ const gchar     *biji_note_obj_get_raw_text                  (BijiNoteObj *note)
 void             biji_note_obj_set_raw_text                  (BijiNoteObj *note,
                                                               const gchar *plain_text);
 
+const char      *biji_note_obj_get_path                      (BijiNoteObj *self);
+
+void             biji_note_obj_set_path                      (BijiNoteObj *self,
+                                                              const char  *path);
+
+const char      *biji_note_obj_get_title                     (BijiNoteObj *self);
 
 gboolean         biji_note_obj_set_title                     (BijiNoteObj* note_obj_ptr,
                                                               const gchar* title);
