@@ -18,13 +18,13 @@
 #include <libxml/xmlwriter.h>
 
 #include "config.h"
+#include "../../bjb-utils.h"
 #include "../biji-string.h"
 #include "../biji-manager.h"
 #include "biji-webkit-editor.h"
 #include "biji-editor-selection.h"
 #include <jsc/jsc.h>
 
-#define INTENSITY(c) ((c->red) * 0.30 + (c->green) * 0.59 + (c->blue) * 0.11)
 #define ZOOM_LARGE  1.5f;
 #define ZOOM_MEDIUM 1.0f;
 #define ZOOM_SMALL  0.8f;
@@ -93,6 +93,7 @@ biji_webkit_editor_get_web_context (void)
     webkit_web_context_set_cache_model (web_context, WEBKIT_CACHE_MODEL_DOCUMENT_VIEWER);
     webkit_web_context_set_process_model (web_context, WEBKIT_PROCESS_MODEL_SHARED_SECONDARY_PROCESS);
     webkit_web_context_set_spell_checking_enabled (web_context, TRUE);
+    webkit_web_context_set_sandbox_enabled (web_context, TRUE);
   }
 
   return web_context;
@@ -200,7 +201,7 @@ biji_webkit_editor_copy (BijiWebkitEditor *self)
 void
 biji_webkit_editor_paste (BijiWebkitEditor *self)
 {
-  webkit_web_view_execute_editing_command (WEBKIT_WEB_VIEW (self), WEBKIT_EDITING_COMMAND_PASTE);
+  webkit_web_view_execute_editing_command (WEBKIT_WEB_VIEW (self), "PasteAsPlainText");
 }
 
 void
@@ -222,7 +223,7 @@ set_editor_color (WebKitWebView *w, GdkRGBA *col)
 
   webkit_web_view_set_background_color (w, col);
   script = g_strdup_printf ("document.getElementById('editable').style.color = '%s';",
-                            INTENSITY (col) < 0.5 ? "white" : "black");
+                            BJB_UTILS_COLOR_INTENSITY (col) < 0.5 ? "white" : "black");
   webkit_web_view_run_javascript (w, script, NULL, NULL, NULL);
 }
 
@@ -390,6 +391,16 @@ on_load_change (WebKitWebView  *web_view,
   }
 }
 
+static gboolean
+on_context_menu (WebKitWebView       *web_view,
+                 WebKitContextMenu   *context_menu,
+                 GdkEvent            *event,
+                 WebKitHitTestResult *hit_test_result,
+                 gpointer             user_data)
+{
+  return TRUE;
+}
+
 static void
 biji_webkit_editor_handle_contents_update (BijiWebkitEditor *self,
                                            JSCValue         *js_value)
@@ -487,7 +498,7 @@ biji_webkit_editor_constructed (GObject *obj)
 
   priv->sel = e_editor_selection_new (view);
 
-  webkit_web_view_set_editable (view, TRUE);
+  webkit_web_view_set_editable (view, !biji_note_obj_is_trashed (BIJI_NOTE_OBJ (priv->note)));
 
   /* Do not segfault at finalize
    * if the note died */
@@ -507,6 +518,8 @@ biji_webkit_editor_constructed (GObject *obj)
                     G_CALLBACK (on_navigation_request), NULL);
   g_signal_connect (view, "load-changed",
                     G_CALLBACK (on_load_change), NULL);
+  g_signal_connect (view, "context-menu",
+                    G_CALLBACK (on_context_menu), NULL);
 }
 
 static void
