@@ -174,7 +174,7 @@ create_note_from_item (BijiMemoItem *item)
 static void
 trash (gpointer urn_uuid, gpointer self)
 {
-  biji_tracker_trash_ressource (
+  biji_tracker_trash_resource (
       biji_provider_get_manager (BIJI_PROVIDER (self)), (gchar*) urn_uuid);
 }
 
@@ -198,7 +198,7 @@ handle_next_item (BijiMemoProvider *self)
     g_debug ("url=%s", item->set.url);
     g_debug ("content=%s\n================\n\n\n", item->set.content);
 
-    biji_tracker_ensure_ressource_from_info (
+    biji_tracker_ensure_resource_from_info (
     biji_provider_get_manager (BIJI_PROVIDER (self)), &item->set);
 
     //memo_item_free (item);
